@@ -915,7 +915,7 @@ strptime_internal (const char *buf, const char *format, struct tm *tm,
 	case 'Y':
 	  /* Match year including century number.  */
 	  get_number (0, INT_MAX);
-	  tm->tm_year = val - (val >= 2000 ? 2000 : 1900);
+	  tm->tm_year = val - 1900;
 	  break;
 	case 'Z':
 	  /* XXX How to handle this?  */
