@@ -62,7 +62,7 @@ extern struct options opt;
 
 /* Global variables share by bindport and acceptport: */
 int msock = -1;
-size_t addrlen;
+int addrlen;
 struct sockaddr *addr;
 struct sockaddr_in srv;
 
