@@ -1300,7 +1300,8 @@ ftp_retrieve_list(urlinfo *u, struct fileinfo *f, ccon *con)
       free(u->local);
       u->local = olocal;
       u->file = ofile;
-      if (err != RETROK)
+      /* Break on fatals.  */
+      if (err == QUOTEXC || err == HOSTERR || err == FWRITEERR)
 	 break;
       con->cmd &= ~(DO_CWD | DO_LOGIN);
       f = f->next;
