@@ -791,17 +791,7 @@ http_loop(urlinfo *u, char **newloc, int *dt)
       fprintf(opt.lfile, "Warning: wildcards not supported in HTTP.\n");
    /* Determine the local filename. */
    if (!u->local)
-   {
-      if (!opt.timestamping || opt.recursive)
-	 u->local = url_filename(u->proxy ? u->proxy : u);
-      else /* opt.timestamping && !recursive */
-      {
-	 if (*(u->proxy ? u->proxy->file : u->file))
-	    u->local = nstrdup(u->proxy ? u->proxy->file : u->file);
-	 else
-	    u->local = nstrdup("index.html");
-      }
-   }
+      u->local = url_filename(u->proxy ? u->proxy : u);
 
    if (!opt.output_document)
       locf = u->local;
