@@ -67,7 +67,7 @@ extern acc_t *netrc_list;
 
    CONOFF  -> integer toggle
    CNUM    -> integer
-   CNUMINF -> integer, with "inf" synomim for 0
+   CNUMINF -> integer, with "inf" synomym for 0
    CSTR    -> free old string, if non-NULL, and strdup val
    CVEC    -> vector
    CSPEC   -> special, has to be treated specially in setval */
@@ -414,7 +414,7 @@ parse_line(const unsigned char *line, unsigned char **com, unsigned char **val)
       return 0;
    }
    /* If the command is invalid, exit now. */
-   if (comind(commands, (char *)*com) == NONE)
+   if (comind(commands, (char *)*com) == -1)
    {
       free(*com);
       return 0;
