@@ -320,8 +320,10 @@ recursive_retrieve(const char *file, const char *this_url,
 	 {
 	    char *p;
 	    /* Just lowercase the hostname.  */
-	    for (p = u->url; *p; p++)
+	    for (p = u->host; *p; p++)
 	       *p = tolower(*p);
+	    free(u->url);
+	    u->url = str_url(u, 0);
 	 }
 	 free(constr);
 	 constr = nstrdup(u->url);
