@@ -69,6 +69,7 @@ char *protostrings[] = {
    "gopher:",
    "hdl:",
    "http:",
+   "https:",
    "ilu:",
    "ior:",
    "irc:",
@@ -731,7 +732,7 @@ get_urls_file(const char *file)
    int size;
    urlpos *first, *current, *old;
 
-   if (!file || strcmp(file, "-"))
+   if (file && !ISHYPHEN(file))
    {
       fp = fopen(file, "r");
       if (!fp)
@@ -791,7 +792,7 @@ get_urls_html(const char *file, const char *this_url, int silent)
    int i, size, no_proto, skip_blanks, first_time;
    urlpos *first, *current, *old;
 
-   if (!file || strcmp(file, "-"))
+   if (file && !ISHYPHEN(file))
    {
       fp = fopen(file, "r");
       if (!fp)
