@@ -419,12 +419,13 @@ exists(const char *filename)
 }
 
 /* Returns 0 if the path is a directory, 1 otherwise. Returns 0 on
-   error. */
+   error.  We use `lstat' instead of `stat' so that 0 is returned for
+   links pointing to directories.  */
 int
 isfile(const char *path)
 {
    struct stat buf;
-   if (stat(path, &buf) != 0)
+   if (lstat(path, &buf) != 0)
       return 0;
    return S_ISDIR(buf.st_mode) ? 0 : 1;
 }
@@ -847,7 +848,7 @@ numdigit(long a)
 {
    int res;
 
-   for (res = 1; a /= 10; res++);
+   for (res = 1; (a /= 10) != 0; res++);
    return res;
 }
 
